.. _collections:

Example Notebooks
=================

.. toctree::
    :glob:
    :hidden:
    :maxdepth: 1

    _collections/examples/README.md

.. raw:: html

    <div class="sphx-glr-thumbnails">

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="JaxSim as a hardware-accelerated parallel physics engine">

.. only:: html

    :doc:`_collections/examples/jaxsim_as_physics_engine`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">JaxSim as a hardware-accelerated parallel physics engine</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="JaxSim for developing closed-loop robot controllers">

.. only:: html

    :doc:`_collections/examples/jaxsim_for_robot_controllers`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">JaxSim for developing closed-loop robot controllers</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="JaxSim as a multibody dynamics library">

.. only:: html

    :doc:`_collections/examples/jaxsim_as_multibody_dynamics_library`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">JaxSim as a multibody dynamics library</div>
    </div>

.. raw:: html

    </div>
